﻿// *****************************************************************
// *                                                               *
// *       Copyright (c) Fast Corporation, 2024                    *
// *                                                               *
// *   All Rights Reserved.  Unpublished rights  reserved  under   *
// *   the copyright laws of the Japan.                            *
// *                                                               *
// *   The software contained on this media  is  proprietary  to   *
// *   and  embodies  the  confidential  technology  of  Fast      *
// *   Corporation.  Possession, use,  duplication  or             *
// *   dissemination of the software and media is authorized only  *
// *   pursuant to a valid written license from Fast Corporation.  *
// *                                                               *
// *****************************************************************
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

// -----------------------------------------------------------------
// FVIL Sample Program
// メインダイアログ
//
// 作成者 : N.Moriguchi
//
// 履歴 : 2024/02/29 初版
//
// PolarTrans Sample Program
// -----------------------------------------------------------------
namespace PolarTrans
{
    public partial class PolarTrans : Form
    {
        //極座標変換クラス
        public FVIL.PolarTrans.CFviPolarTrans m_PolarTrans = new FVIL.PolarTrans.CFviPolarTrans();
        //極座標変換パラメータ構造クラス
        public FVIL.PolarTrans.CFviPolarTransParam m_PolarTransParam = new FVIL.PolarTrans.CFviPolarTransParam();

        //入力画像
        public FVIL.Data.CFviImage m_SrcImage = new FVIL.Data.CFviImage();
        //変換後画像
        public FVIL.Data.CFviImage m_DstImage = new FVIL.Data.CFviImage();

        public PolarTrans()
        {
            InitializeComponent();
        }

        /// <summary>
        /// フォーム表示開始
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 使用許諾を確認します。
        /// </remarks>
        private void Form1_Shown(object sender, EventArgs e)
        {
            //使用許諾の確認
            dialogLicence licence_dialog = new dialogLicence();
            if ((licence_dialog.ShowDialog(this) != DialogResult.OK))
            {
                this.Close();
                //使用許諾が得られない場合はサンプルプログラムの動作を終了
                return;
            }
        }

        /// <summary>
        /// メインフォーム初期化
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// メインフォームの初期化処理。
        /// </remarks>
        private void Form1_Load(object sender, EventArgs e)
        {
            //FVILライブラリの初期化
            FVIL._SetUp.InitVisionLibrary();

            //パラメータ初期値設定
            //変換方向
            m_PolarTrans.Invert = false;    //false:矩形→円形
            comboBoxInvert.Items.Clear();
            comboBoxInvert.Items.Add("矩形 → 円形");
            comboBoxInvert.Items.Add("円形 → 矩形");
            comboBoxInvert.SelectedIndex = 0;

            //背景処理
            m_PolarTrans.ClearBackMode = true;    //true:0クリアする
            comboBoxClearBack.Items.Clear();
            comboBoxClearBack.Items.Add("0クリアする");
            comboBoxClearBack.Items.Add("処理しない");
            comboBoxClearBack.SelectedIndex = 0;

            //濃度補間方法
            m_PolarTrans.SamplingMode = FVIL.PolarTrans.SamplingMode.NearestNeighbor;
            comboBoxSamplingMode.Items.Clear();
            comboBoxSamplingMode.Items.Add("NearestNeighbor");
            comboBoxSamplingMode.Items.Add("Bilinear");
            comboBoxSamplingMode.Items.Add("Cubic");
            comboBoxSamplingMode.SelectedIndex = 0;

            //基準座標モード
            m_PolarTrans.Param.CoordinateMode = FVIL.PolarTrans.CoordinateMode.Left;
            comboBoxCoordinateMode.Items.Clear();
            comboBoxCoordinateMode.Items.Add("Upper(右上)");
            comboBoxCoordinateMode.Items.Add("Lower(左下)");
            comboBoxCoordinateMode.Items.Add("Left(左上)");
            comboBoxCoordinateMode.Items.Add("Right(右下)");
            comboBoxCoordinateMode.SelectedIndex = 2;

            //極座標変換パラメータの設定
            m_PolarTransParam = m_PolarTrans.Param;

            //矩形領域の基準座標
            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y);
            textBoxOriginInX.Text = m_PolarTransParam.OriginIn.X.ToString("0.0");
            textBoxOriginInY.Text = m_PolarTransParam.OriginIn.Y.ToString("0.0");

            //矩形領域サイズ
            m_PolarTransParam.Width = m_SrcImage.Window.Width;
            m_PolarTransParam.Height = m_SrcImage.Window.Height;
            numericUpDownWidth.Value = (decimal)m_PolarTransParam.Width;
            numericUpDownHeight.Value = (decimal)m_PolarTransParam.Height;

            //円形領域の回転中心座標
            m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_PolarTransParam.Width, m_PolarTransParam.Width);
            textBoxOriginOutX.Text = m_PolarTransParam.OriginOut.X.ToString("0.0");
            textBoxOriginOutY.Text = m_PolarTransParam.OriginOut.Y.ToString("0.0");

            //円形領域の半径
            m_PolarTransParam.Radius = m_PolarTransParam.Width;
            numericUpDownRadius.Value = (decimal)m_PolarTransParam.Radius;

            //円形領域の回転開始角度
            m_PolarTransParam.StartAngle = new FVIL.Data.CFviAngle(270.0);
            textBoxStartAngle.Text = m_PolarTransParam.StartAngle.Degree.ToString("0.0");

            //円形領域の回転範囲
            m_PolarTransParam.RangeAngle = new FVIL.Data.CFviAngle(360.0);
            textBoxRangeAngle.Text = m_PolarTransParam.RangeAngle.Degree.ToString("0.0");
        }

        /// <summary>
        /// LoadFile ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 入力画像ファイルのロード
        /// </remarks>
        private void buttonLoadFile_Click(object sender, EventArgs e)
        {
            //入力画像ファイルのロード
            openFileDialog1.FileName = null;
            openFileDialog1.Filter = "Bitmap ファイル (*.bmp;*.dib)|*.bmp;*.dib";
            openFileDialog1.Filter += "|Png ファイル (*.png)|*.png";
            openFileDialog1.Filter += "|Jpeg ファイル (*.jpg;*.jpeg)|*.jpg;*.jpeg";
            openFileDialog1.Filter += "|Tiff ファイル (*.tif;*.tiff)|*.tif;*.tiff";
            openFileDialog1.DefaultExt = "*.bmp";

            if ((openFileDialog1.FileNames.Length <= 0) && (openFileDialog1.ShowDialog(this) == DialogResult.Cancel))
                return;

            try
            {
                FVIL.File.Function.LoadImageFile(openFileDialog1.FileName, m_SrcImage, FVIL.PixelMode.Unpacking);
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            //描画imageのセット
            cFviImageView1.Image = m_SrcImage;
            radioButtonDisplaySrc.Checked = true;

            //パラメータ更新
            switch(comboBoxCoordinateMode.SelectedIndex)
            {
                case 0:
                    //Upper(右上)
                    if (comboBoxInvert.SelectedIndex == 0)
                    {
                        //矩形 → 円形
                        //矩形領域の基準座標
                        m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Y);
                        textBoxOriginInX.Text = m_SrcImage.Window.Width.ToString("0.0");
                        textBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0");
                        //円形領域の回転中心座標
                        m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_SrcImage.Window.Height, m_SrcImage.Window.Height);
                        textBoxOriginOutX.Text = m_SrcImage.Window.Height.ToString("0.0");
                        textBoxOriginOutY.Text = m_SrcImage.Window.Height.ToString("0.0");
                        //円形領域の半径
                        m_PolarTransParam.Radius = m_SrcImage.Window.Height;
                        numericUpDownRadius.Value = m_SrcImage.Window.Height;
                    }
                    else
                    {
                        //円形 → 矩形
                        //矩形領域の基準座標
                        m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), m_SrcImage.Window.Y);
                        textBoxOriginInX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                        textBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0");
                    }
                    break;
                case 1:
                    //Lower(左下)
                    if (comboBoxInvert.SelectedIndex == 0)
                    {
                        //矩形 → 円形
                        //矩形領域の基準座標
                        m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Height);
                        textBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0");
                        textBoxOriginInY.Text = m_SrcImage.Window.Height.ToString("0.0");
                        //円形領域の回転中心座標
                        m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_SrcImage.Window.Height, m_SrcImage.Window.Height);
                        textBoxOriginOutX.Text = m_SrcImage.Window.Height.ToString("0.0");
                        textBoxOriginOutY.Text = m_SrcImage.Window.Height.ToString("0.0");
                        //円形領域の半径
                        m_PolarTransParam.Radius = m_SrcImage.Window.Height;
                        numericUpDownRadius.Value = m_SrcImage.Window.Height;
                    }
                    else
                    {
                        //円形 → 矩形
                        //矩形領域の基準座標
                        m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, (m_SrcImage.Window.Width / 2));
                        textBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0");
                        textBoxOriginInY.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                    }
                    break;
                case 2:
                    //Left(左上)
                    if (comboBoxInvert.SelectedIndex == 0)
                    {
                        //矩形 → 円形
                        //矩形領域の基準座標
                        m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y);
                        textBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0");
                        textBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0");
                        //円形領域の回転中心座標
                        m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Width);
                        textBoxOriginOutX.Text = m_SrcImage.Window.Width.ToString("0.0");
                        textBoxOriginOutY.Text = m_SrcImage.Window.Width.ToString("0.0");
                        //円形領域の半径
                        m_PolarTransParam.Radius = m_SrcImage.Window.Width;
                        numericUpDownRadius.Value = m_SrcImage.Window.Width;
                    }
                    else
                    {
                        //円形 → 矩形
                        //矩形領域の基準座標
                        m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y);
                        textBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0");
                        textBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0");
                    }
                    break;
                case 3:
                    //Right(右下)
                    if (comboBoxInvert.SelectedIndex == 0)
                    {
                        //矩形 → 円形
                        //矩形領域の基準座標
                        m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Height);
                        textBoxOriginInX.Text = m_SrcImage.Window.Width.ToString("0.0");
                        textBoxOriginInY.Text = m_SrcImage.Window.Height.ToString("0.0");
                        //円形領域の回転中心座標
                        m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Width);
                        textBoxOriginOutX.Text = m_SrcImage.Window.Width.ToString("0.0");
                        textBoxOriginOutY.Text = m_SrcImage.Window.Width.ToString("0.0");
                        //円形領域の半径
                        m_PolarTransParam.Radius = m_SrcImage.Window.Width;
                        numericUpDownRadius.Value = m_SrcImage.Window.Width;
                    }
                    else
                    {
                        //円形 → 矩形
                        //矩形領域の基準座標
                        m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), (m_SrcImage.Window.Width / 2));
                        textBoxOriginInX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                        textBoxOriginInY.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                    }
                    break;
            }

            if (comboBoxInvert.SelectedIndex == 0)
            {
                //矩形 → 円形
                //矩形領域サイズ
                m_PolarTransParam.Width = m_SrcImage.Window.Width;
                numericUpDownWidth.Value = m_SrcImage.Window.Width;
                m_PolarTransParam.Height = m_SrcImage.Window.Height;
                numericUpDownHeight.Value = m_SrcImage.Window.Height;
            }
            else
            {
                //円形 → 矩形
                //矩形領域サイズ
                m_PolarTransParam.Width = (m_SrcImage.Window.Width / 2);
                numericUpDownWidth.Value = (m_SrcImage.Window.Width / 2);
                m_PolarTransParam.Height = (m_SrcImage.Window.Height / 2);
                numericUpDownHeight.Value = (m_SrcImage.Window.Height / 2);
                //円形領域の回転中心座標
                m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), (m_SrcImage.Window.Height / 2));
                textBoxOriginOutX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                textBoxOriginOutY.Text = (m_SrcImage.Window.Height / 2).ToString("0.0");
                //円形領域の半径
                m_PolarTransParam.Radius = (m_SrcImage.Window.Width / 2);
                numericUpDownRadius.Value = (m_SrcImage.Window.Width / 2);
            }

            //再描画
            cFviImageView1.Refresh();
        }

        /// <summary>
        /// 極座標変換実行ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 極座標変換処理
        /// </remarks>
        private void buttonExecute_Click(object sender, EventArgs e)
        {
            try
            {
                //処理対象画像の有効性検査
                int valid = FVIL.PolarTrans.CFviPolarTrans.CheckValidity(m_SrcImage);
                if (valid != FVIL.ErrorCode._SUCCESS)
                {
                    //エラー処理
                    MessageBox.Show("画像種別が不正です", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }

                //画像準備
                m_PolarTrans.SrcImages[0] = m_SrcImage;
                m_PolarTrans.DstImages[0] = m_DstImage;

                //出力画像の有効化
                m_PolarTrans.Validate(1);

                //極座標変換実行
                m_PolarTrans.Execute();

                //描画imageのセット
                cFviImageView1.Image = m_DstImage;
                radioButtonDisplayDst.Checked = true;
                //再描画
                cFviImageView1.Refresh();
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Save Imageボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 表示画像保存。
        /// </remarks>
        private void buttonSaveImage_Click(object sender, EventArgs e)
        {
            SaveFileDialog ofdlg = new SaveFileDialog();

            ofdlg.Filter = "画像ファイル(*.bmp;*.dib;*.png;*.jpg;*.jpeg;*.tif;*.tiff;*.raw;*.pat)|*.bmp;*.dib;*.png;*.jpg;*.jpeg;*.tif;*.tiff;*.raw;*.pat";
            ofdlg.Filter += "|Bitmap ファイル (*.bmp;*.dib)|*.bmp;*.dib";
            ofdlg.Filter += "|Png ファイル (*.png)|*.png";
            ofdlg.Filter += "|Jpeg ファイル (*.jpg;*.jpeg)|*.jpg;*.jpeg";
            ofdlg.Filter += "|Tiff ファイル (*.tif;*.tiff)|*.tif;*.tiff";
            ofdlg.Filter += "|Raw ファイル (*.raw)|*.raw";
            ofdlg.Filter += "|すべてのファイル (*.*)|*.*";
            ofdlg.OverwritePrompt = true;

            if (ofdlg.ShowDialog(this) == DialogResult.OK)
            {
                try
                {
                    //この関数は、簡易的に画像ファイルの保存を行う為のものです。 
                    //この関数で指定できないパラメータを指定する必要があれば、 各画像ファイルアクセスクラスを直接使用してください。 
                    FVIL.File.Function.SaveImageFile(ofdlg.FileName, cFviImageView1.Image);

                }
                catch (FVIL.CFviException ex)
                {
                    System.String msg = System.String.Format("ライブラリが例外を発行しました。code={0} func={1}", ex.ErrorCode, ex.Function);
                    switch ((ex.ErrorCode))
                    {
                        case FVIL.ErrorCode.NOT_SUPPORTED:
                        case FVIL.ErrorCode.INVALID_OBJECT:
                            msg += "\r\n" + "サポートされていない画像オブジェクトです。";
                            msg += "\r\n" + "Raw 形式で保存してください。";
                            break;
                    }
                    //エラー処理
                    MessageBox.Show(msg, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
                catch (Exception ex)
                {
                    //エラー処理
                    MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        /// <summary>
        /// 表示画像切替えラジオボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 入力画像を表示します。
        /// </remarks>
        private void radioButtonDisplaySrc_CheckedChanged(object sender, EventArgs e)
        {
            //入力画像のセット
            cFviImageView1.Image = m_SrcImage;
            //再描画
            cFviImageView1.Refresh();
        }

        /// <summary>
        /// 表示画像切替えラジオボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 出力画像を表示します。
        /// </remarks>
        private void radioButtonDisplayDst_CheckedChanged(object sender, EventArgs e)
        {
            //出力画像のセット
            cFviImageView1.Image = m_DstImage;
            //再描画
            cFviImageView1.Refresh();
        }

        /// <summary>
        /// 変換方向の反転フラグ
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 通常方向(false)・逆方向(true)の選択。
        /// </remarks>
        private void comboBoxInvert_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                if (comboBoxInvert.SelectedIndex == 0)
                {
                    //矩形→円形
                    m_PolarTrans.Invert = false;
                    //パラメータ更新
                    switch (comboBoxCoordinateMode.SelectedIndex)
                    {
                        case 0:
                            //Upper(右上)
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Y);
                            textBoxOriginInX.Text = m_SrcImage.Window.Width.ToString("0.0");
                            textBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0");
                            //円形領域の回転中心座標
                            m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_SrcImage.Window.Height, m_SrcImage.Window.Height);
                            textBoxOriginOutX.Text = m_SrcImage.Window.Height.ToString("0.0");
                            textBoxOriginOutY.Text = m_SrcImage.Window.Height.ToString("0.0");
                            //円形領域の半径
                            m_PolarTransParam.Radius = m_SrcImage.Window.Height;
                            numericUpDownRadius.Value = m_SrcImage.Window.Height; 
                            break;
                        case 1:
                            //Lower(左下)
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Height);
                            textBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0");
                            textBoxOriginInY.Text = m_SrcImage.Window.Height.ToString("0.0");
                            //円形領域の回転中心座標
                            m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_SrcImage.Window.Height, m_SrcImage.Window.Height);
                            textBoxOriginOutX.Text = m_SrcImage.Window.Height.ToString("0.0");
                            textBoxOriginOutY.Text = m_SrcImage.Window.Height.ToString("0.0");
                            //円形領域の半径
                            m_PolarTransParam.Radius = m_SrcImage.Window.Height;
                            numericUpDownRadius.Value = m_SrcImage.Window.Height;
                            break;
                        case 2:
                            //Left(左上)
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y);
                            textBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0");
                            textBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0");
                            //円形領域の回転中心座標
                            m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Width);
                            textBoxOriginOutX.Text = m_SrcImage.Window.Width.ToString("0.0");
                            textBoxOriginOutY.Text = m_SrcImage.Window.Width.ToString("0.0");
                            //円形領域の半径
                            m_PolarTransParam.Radius = m_SrcImage.Window.Width;
                            numericUpDownRadius.Value = m_SrcImage.Window.Width;
                            break;
                        case 3:
                            //Right(右下)
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Height);
                            textBoxOriginInX.Text = m_SrcImage.Window.Width.ToString("0.0");
                            textBoxOriginInY.Text = m_SrcImage.Window.Height.ToString("0.0");
                            //円形領域の回転中心座標
                            m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Width);
                            textBoxOriginOutX.Text = m_SrcImage.Window.Width.ToString("0.0");
                            textBoxOriginOutY.Text = m_SrcImage.Window.Width.ToString("0.0");
                            //円形領域の半径
                            m_PolarTransParam.Radius = m_SrcImage.Window.Width;
                            numericUpDownRadius.Value = m_SrcImage.Window.Width;
                            break;
                    }
                    //矩形領域サイズ
                    m_PolarTransParam.Width = m_SrcImage.Window.Width;
                    numericUpDownWidth.Value = m_SrcImage.Window.Width;
                    m_PolarTransParam.Height = m_SrcImage.Window.Height;
                    numericUpDownHeight.Value = m_SrcImage.Window.Height;
                }
                else
                {
                    //円形→矩形
                    m_PolarTrans.Invert = true;
                    //パラメータ更新
                    switch (comboBoxCoordinateMode.SelectedIndex)
                    {
                        case 0:
                            //Upper(右上)
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), m_SrcImage.Window.Y);
                            textBoxOriginInX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                            textBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0");
                            break;
                        case 1:
                            //Lower(左下)
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, (m_SrcImage.Window.Width / 2));
                            textBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0");
                            textBoxOriginInY.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                            break;
                        case 2:
                            //Left(左上)
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y);
                            textBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0");
                            textBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0");
                            break;
                        case 3:
                            //Right(右下)
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), (m_SrcImage.Window.Width / 2));
                            textBoxOriginInX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                            textBoxOriginInY.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                            break;
                    }
                    //矩形領域サイズ
                    m_PolarTransParam.Width = (m_SrcImage.Window.Width / 2);
                    numericUpDownWidth.Value = (m_SrcImage.Window.Width / 2);
                    m_PolarTransParam.Height = (m_SrcImage.Window.Height / 2);
                    numericUpDownHeight.Value = (m_SrcImage.Window.Height / 2);
                    //円形領域の回転中心座標
                    m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), (m_SrcImage.Window.Height / 2));
                    textBoxOriginOutX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                    textBoxOriginOutY.Text = (m_SrcImage.Window.Height / 2).ToString("0.0");
                    //円形領域の半径
                    m_PolarTransParam.Radius = (m_SrcImage.Window.Width / 2);
                    numericUpDownRadius.Value = (m_SrcImage.Window.Width / 2);
                }
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// 領域外画素の処理方法
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// ０クリア(true)・処理しない(false)の選択。
        /// </remarks>
        private void comboBoxClearBack_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                switch (comboBoxClearBack.SelectedIndex)
                {
                    case 0:
                        //0クリアする
                        m_PolarTrans.ClearBackMode = true;
                        break;
                    case 1:
                        //処理しない
                        m_PolarTrans.ClearBackMode = false;
                        break;
                }
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// 濃度補間方法
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// NearestNeighbor・Bilinear・Cubicの選択。
        /// </remarks>
        private void comboBoxSamplingMode_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                switch (comboBoxSamplingMode.SelectedIndex)
                {
                    case 0:
                        //NearestNeighbor
                        m_PolarTrans.SamplingMode = FVIL.PolarTrans.SamplingMode.NearestNeighbor;
                        break;
                    case 1:
                        //Bilinear
                        m_PolarTrans.SamplingMode = FVIL.PolarTrans.SamplingMode.Bilinear;
                        break;
                    case 2:
                        //Cubic
                        m_PolarTrans.SamplingMode = FVIL.PolarTrans.SamplingMode.Cubic;
                        break;
                }
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// 基準座標モード
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// Upper・Lower・Left・Rightの選択。
        /// </remarks>
        private void comboBoxCoordinateMode_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                switch (comboBoxCoordinateMode.SelectedIndex)
                {
                    case 0:
                        //Upper(右上)
                        m_PolarTrans.Param.CoordinateMode = FVIL.PolarTrans.CoordinateMode.Upper;
                        if (comboBoxInvert.SelectedIndex == 0)
                        {
                            //矩形 → 円形
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Y);
                            textBoxOriginInX.Text = m_SrcImage.Window.Width.ToString("0.0");
                            textBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0");
                            //円形領域の回転中心座標
                            m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_SrcImage.Window.Height, m_SrcImage.Window.Height);
                            textBoxOriginOutX.Text = m_SrcImage.Window.Height.ToString("0.0");
                            textBoxOriginOutY.Text = m_SrcImage.Window.Height.ToString("0.0");
                            //円形領域の半径
                            m_PolarTransParam.Radius = m_SrcImage.Window.Height;
                            numericUpDownRadius.Value = m_SrcImage.Window.Height;
                        }
                        else
                        {
                            //円形 → 矩形
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), m_SrcImage.Window.Y);
                            textBoxOriginInX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                            textBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0");
                        }
                        break;
                    case 1:
                        //Lower(左下)
                        m_PolarTrans.Param.CoordinateMode = FVIL.PolarTrans.CoordinateMode.Lower;
                        if (comboBoxInvert.SelectedIndex == 0)
                        {
                            //矩形 → 円形
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Height);
                            textBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0");
                            textBoxOriginInY.Text = m_SrcImage.Window.Height.ToString("0.0");
                            //円形領域の回転中心座標
                            m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_SrcImage.Window.Height, m_SrcImage.Window.Height);
                            textBoxOriginOutX.Text = m_SrcImage.Window.Height.ToString("0.0");
                            textBoxOriginOutY.Text = m_SrcImage.Window.Height.ToString("0.0");
                            //円形領域の半径
                            m_PolarTransParam.Radius = m_SrcImage.Window.Height;
                            numericUpDownRadius.Value = m_SrcImage.Window.Height;
                        }
                        else
                        {
                            //円形 → 矩形
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, (m_SrcImage.Window.Width / 2));
                            textBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0");
                            textBoxOriginInY.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                        }
                        break;
                    case 2:
                        //Left(左上)
                        m_PolarTrans.Param.CoordinateMode = FVIL.PolarTrans.CoordinateMode.Left;
                        if (comboBoxInvert.SelectedIndex == 0)
                        {
                            //矩形 → 円形
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y);
                            textBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0");
                            textBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0");
                            //円形領域の回転中心座標
                            m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Width);
                            textBoxOriginOutX.Text = m_SrcImage.Window.Width.ToString("0.0");
                            textBoxOriginOutY.Text = m_SrcImage.Window.Width.ToString("0.0");
                            //円形領域の半径
                            m_PolarTransParam.Radius = m_SrcImage.Window.Width;
                            numericUpDownRadius.Value = m_SrcImage.Window.Width;
                        }
                        else
                        {
                            //円形 → 矩形
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y);
                            textBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0");
                            textBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0");
                        }
                        break;
                    case 3:
                        //Right(右下)
                        m_PolarTrans.Param.CoordinateMode = FVIL.PolarTrans.CoordinateMode.Right;
                        if (comboBoxInvert.SelectedIndex == 0)
                        {
                            //矩形 → 円形
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Height);
                            textBoxOriginInX.Text = m_SrcImage.Window.Width.ToString("0.0");
                            textBoxOriginInY.Text = m_SrcImage.Window.Height.ToString("0.0");
                            //円形領域の回転中心座標
                            m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Width);
                            textBoxOriginOutX.Text = m_SrcImage.Window.Width.ToString("0.0");
                            textBoxOriginOutY.Text = m_SrcImage.Window.Width.ToString("0.0");
                            //円形領域の半径
                            m_PolarTransParam.Radius = m_SrcImage.Window.Width;
                            numericUpDownRadius.Value = m_SrcImage.Window.Width;
                        }
                        else
                        {
                            //円形 → 矩形
                            //矩形領域の基準座標
                            m_PolarTransParam.OriginIn = new FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), (m_SrcImage.Window.Width / 2));
                            textBoxOriginInX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                            textBoxOriginInY.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                        }
                        break;
                }

                if (comboBoxInvert.SelectedIndex == 0)
                {
                    //矩形 → 円形
                    //矩形領域サイズ
                    m_PolarTransParam.Width = m_SrcImage.Window.Width;
                    numericUpDownWidth.Value = m_SrcImage.Window.Width;
                    m_PolarTransParam.Height = m_SrcImage.Window.Height;
                    numericUpDownHeight.Value = m_SrcImage.Window.Height;
                }
                else
                {
                    //円形 → 矩形
                    //矩形領域サイズ
                    m_PolarTransParam.Width = (m_SrcImage.Window.Width / 2);
                    numericUpDownWidth.Value = (m_SrcImage.Window.Width / 2);
                    m_PolarTransParam.Height = (m_SrcImage.Window.Height / 2);
                    numericUpDownHeight.Value = (m_SrcImage.Window.Height / 2);
                    //円形領域の回転中心座標
                    m_PolarTransParam.OriginOut = new FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), (m_SrcImage.Window.Height / 2));
                    textBoxOriginOutX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0");
                    textBoxOriginOutY.Text = (m_SrcImage.Window.Height / 2).ToString("0.0");
                    //円形領域の半径
                    m_PolarTransParam.Radius = (m_SrcImage.Window.Width / 2);
                    numericUpDownRadius.Value = (m_SrcImage.Window.Width / 2);
                }
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// 矩形領域の基準座標
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 矩形領域の基準座標（X座標）の設定。
        /// </remarks>
        private void textBoxOriginInX_TextChanged(object sender, EventArgs e)
        {
            try
            {
                FVIL.Data.CFviPoint point = new FVIL.Data.CFviPoint();
                point.X = double.Parse(textBoxOriginInX.Text);
                point.Y = m_PolarTransParam.OriginIn.Y;
                m_PolarTransParam.OriginIn = point;
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// 矩形領域の基準座標
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 矩形領域の基準座標（Y座標）の設定。
        private void textBoxOriginInY_TextChanged(object sender, EventArgs e)
        {
            try
            {
                FVIL.Data.CFviPoint point = new FVIL.Data.CFviPoint();
                point.X = m_PolarTransParam.OriginIn.X;
                point.Y = double.Parse(textBoxOriginInY.Text);
                m_PolarTransParam.OriginIn = point;
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        /// <summary>
        /// 矩形領域サイズ
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 矩形領域サイズ（幅）の設定。
        private void numericUpDownWidth_ValueChanged(object sender, EventArgs e)
        {
            try
            {
                m_PolarTransParam.Width = (double)numericUpDownWidth.Value;
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// 矩形領域サイズ
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 矩形領域サイズ（高さ）の設定。
        private void numericUpDownHeight_ValueChanged(object sender, EventArgs e)
        {
            try
            {
                m_PolarTransParam.Height = (double)numericUpDownHeight.Value;
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// 円形領域の回転中心座標
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 円形領域の回転中心座標（X座標）の設定。
        private void textBoxOriginOutX_TextChanged(object sender, EventArgs e)
        {
            try
            {
                FVIL.Data.CFviPoint point = new FVIL.Data.CFviPoint();
                point.X = double.Parse(textBoxOriginOutX.Text);
                point.Y = m_PolarTransParam.OriginOut.Y;
                m_PolarTransParam.OriginOut = point;
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// 円形領域の回転中心座標
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 円形領域の回転中心座標（Y座標）の設定。
        private void textBoxOriginOutY_TextChanged(object sender, EventArgs e)
        {
            try
            {
                FVIL.Data.CFviPoint point = new FVIL.Data.CFviPoint();
                point.X = m_PolarTransParam.OriginOut.X;
                point.Y = double.Parse(textBoxOriginOutY.Text);
                m_PolarTransParam.OriginOut = point;
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// 円形領域の半径
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 円形領域の半径の設定。
        private void numericUpDownRadius_ValueChanged(object sender, EventArgs e)
        {
            try
            {
                m_PolarTransParam.Radius = (double)numericUpDownRadius.Value;
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// 円形領域の回転開始角度
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 円形領域の回転開始角度の設定。
        private void textBoxStartAngle_TextChanged(object sender, EventArgs e)
        {
            try
            {
                if(double.Parse(textBoxStartAngle.Text) < 0)
                {
                    textBoxStartAngle.Text = "0.0";
                    m_PolarTransParam.StartAngle = new FVIL.Data.CFviAngle(0.0);
                }
                else if (double.Parse(textBoxStartAngle.Text) >= 359.9)
                {
                    textBoxStartAngle.Text = "359.9";
                    m_PolarTransParam.StartAngle = new FVIL.Data.CFviAngle(359.9);
                }
                else
                {
                    m_PolarTransParam.StartAngle = new FVIL.Data.CFviAngle(double.Parse(textBoxStartAngle.Text));
                }
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// 円形領域の回転範囲
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 円形領域の回転範囲。
        private void textBoxRangeAngle_TextChanged(object sender, EventArgs e)
        {
            try
            {
                if (double.Parse(textBoxRangeAngle.Text) < -360.0)
                {
                    textBoxRangeAngle.Text = "-360.0";
                    m_PolarTransParam.RangeAngle = new FVIL.Data.CFviAngle(-360.0);
                }
                else if (double.Parse(textBoxRangeAngle.Text) > 360.0)
                {
                    textBoxRangeAngle.Text = "360.0";
                    m_PolarTransParam.RangeAngle = new FVIL.Data.CFviAngle(360.0);
                }
                else
                {
                    m_PolarTransParam.RangeAngle = new FVIL.Data.CFviAngle(double.Parse(textBoxRangeAngle.Text));
                }
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// x１ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 等倍で表示します。
        /// </remarks>
        private void buttonMag1_Click(object sender, EventArgs e)
        {
            //画像の表示倍率の取得または設定を行います。1.0と指定すると等倍で表示します。
            //倍率値は、0.5とした場合は、幅・高さ共に1/2となり、面積が1/4になります。
            //3.0とした場合は、幅・高さ共に3倍となり、面積が9倍になります。

            //表示倍率の設定
            cFviImageView1.Display.Magnification = 1.0;
            //再描画
            cFviImageView1.Refresh();
        }

        /// <summary>
        /// Fitボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 画像全体がビューのクライアント領域に表示できるように表示倍率を縮小(または拡大)します。
        /// </remarks>
        private void buttonFit_Click(object sender, EventArgs e)
        {
            //画像全体がビューのクライアント領域に表示できるように表示倍率を縮小(または拡大)します
            //表示倍率を調整
            cFviImageView1.FitImageSize();
            //再描画
            cFviImageView1.Refresh();
        }

        /// <summary>
        /// ＋ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 現在の倍率に0.5加えた倍率で表示します。
        /// </remarks>
        private void buttonPlus_Click(object sender, EventArgs e)
        {
            double Value = 0;
            //現倍率の取得
            Value = cFviImageView1.Display.Magnification;
            //表示倍率の設定
            Value = Value + 0.5;
            cFviImageView1.Display.Magnification = Value;
            //再描画
            cFviImageView1.Refresh();
        }

        /// <summary>
        /// －ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 現在の倍率から0.5引いた倍率で表示します。ただし、倍率が０以下になる場合は倍率0.1で表示します。
        /// </remarks>
        private void buttonMinus_Click(object sender, EventArgs e)
        {
            double Value = 0;
            //現倍率の取得
            Value = cFviImageView1.Display.Magnification;
            Value = Value - 0.5;
            if (Value <= 0)
            {
                //0以下を設定するとエラーになるので0.1を設定する
                Value = 0.1;
            }
            //表示倍率の設定
            cFviImageView1.Display.Magnification = Value;
            //再描画
            cFviImageView1.Refresh();
        }

        /// <summary>
        /// Ascopeチェックボックス
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// ASCOPEの表示を切替えます。
        /// </remarks>
        private void checkBoxAscope_CheckedChanged(object sender, EventArgs e)
        {
            //ASCOPEオーバレイの設定
            if (checkBoxAscope.Checked)
            {
                //ASCOPEの表示を有効にする。
                cFviImageView1.Display.OverlayAscope.Active = true;
            }
            else
            {
                //ASCOPEの表示を無効にする。
                cFviImageView1.Display.OverlayAscope.Active = false;
            }
            //再描画
            cFviImageView1.Refresh();
        }


    }
}
